====================
Resources
====================

Credit risk modelling has been covered in great detail by many excellent 
authors. The list of resources in this page presents only a small
selection of references that contains information about credit
risk modelling and validation. 

1. `Instructions for reporting the validation results of internal models. ECB, 2019 <https://www.bankingsupervision.europa.eu/banking/tasks/internal_models/shared/pdf/instructions_validation_reporting_credit_risk.en.pdf>`_.
2. `Studies on the Validation of Internal Rating Systems. Basel Committee, 2005 <https://www.bis.org/publ/bcbs_wp14.pdf>`_.
3. `scikit-learn User Guide <https://scikit-learn.org/stable/user_guide.html>`_.
